# ordr.py

![PyPI - Downloads](https://img.shields.io/pypi/dm/ordr.py)
![PyPI - License](https://img.shields.io/pypi/l/ordr.py)
![PyPI](https://img.shields.io/pypi/v/ordr.py)
![GitHub issues](https://img.shields.io/github/issues/itsrqtl/ordr.py)
![GitHub pull requests](https://img.shields.io/github/issues-pr/itsrqtl/ordr.py)

**Easy to use, Simple: API and Websocket wrapper for o!rdr services.**

## Installation

```py
pip install ordr.py
```

## Documentation

- [Documentation](/docs/DOCS.md)
- [changelog](/CHANGELOG.md)

## Credits

- [o!rdr API](https://ordr.issou.best/docs)

## License

This project is licensed under `MIT License`. See the [LICENSE](/LICENSE) for more details.
